#
# INIparse v1.2
#      by Waster_
#
# Usage:
#   readini <filename> <itemname>
#         Reads <itemname> from <filename>. If cannot find file
#      or <itemname>, returns an empty string.
#
#   writeini <filename> <itemname> <itemvalue>
#         Writes/modifies <itemname> in <filename>. If cannot
#      file or cannot find <itemname> in it, creates a new one.
#         Also, deletes empty and Whitespace-Only (spaces,tabs)
#      lines in <filename>.
#
#   removeini <filename> <itemname>
#         Deletes <itemname> in <filename>. If cannot find file
#      returns.
#         Also, deletes empty and Whitespace-Only (spaces,tabs)
#      lines in <filename>.
#
#   renameini <filename> <olditemname> <newitemname>
#         Renames <olditemname> to <newitemname> in <filename>.
#         Also, deletes empty and Whitespace-Only (spaces,tabs)
#      lines in <filename>.
#
#
# Thanks to Djsmoke for "removeini" idea.
#
# Contact author at:
#    EMail : waster@iname.com
#    ICQ   : 27216346
#

proc rtrimleft {bigstr srcstr} {
set istring1 [string length $srcstr]
if {$srcstr == [string range $bigstr 0 [expr $istring1-1]]} {
  return [string range $bigstr $istring1 end] }
}

proc readini {file item} {
set itemlength [string length $item]
set item $item=

  if {[catch {set fname [open $file]}]!=0} {return ""}

  while {[eof $fname]!=1} {
	set line [gets $fname]
	if {[string range $line 0 $itemlength]==$item} {
		close $fname
		return [rtrimleft $line $item]}
  }
  close $fname
}

proc writeini {file item value} {
set fileline ""
set found 0
set itemlength [string length $item]
set item $item=

  if {[catch {set fname [open $file r+]}]!=0} {set fname [open $file w+]}

  while {[eof $fname]!=1} {
	set abc [gets $fname]
	if {[string trim $abc]!=""} {lappend fileline $abc}
  }

  close $fname
  set fname [open $file w+]  ;#We cause the file to be emptied

  foreach line $fileline {
	if {$found==0 && [string range $line 0 $itemlength]==$item} {
		puts $fname $item$value
		set found 1
		continue
	}
	puts $fname $line
  }

  if {$found==0} {puts $fname $item$value}
  close $fname
}

proc removeini {file item} {
set fileline ""
set found 0
set itemlength [string length $item]
set item $item=

  if {[catch {set fname [open $file r+]}]!=0} {return}

  while {[eof $fname]!=1} {
	set abc [gets $fname]
	if {[string trim $abc]!=""} {lappend fileline $abc}
  }

  close $fname
  set fname [open $file w+]  ;#We cause the file to be emptied

  foreach line $fileline {
	if {$found=="0" && [string range $line 0 $itemlength]==$item} {
		set found 1
		continue
	}
	puts $fname $line
  }

  close $fname
}

proc renameini {file olditem newitem} {
  set a [readini $file $olditem]
  removeini $file $olditem
  writeini $file $newitem $a
}
